@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 from PyQt4 import QtCore, QtGui
-from qtUImain import Ui_MainWindow
+from qtGUI.qtUImain import Ui_MainWindow
+from qtGUI.aboutDialog import Ui_aboutDialog
 from sys import argv
 from os import path
 
@@ -66,6 +67,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.removeprogression,
 			QtCore.SIGNAL("clicked()"),
 			self.remove_progression)
+		self.connect(self.ui.action_About,
+			QtCore.SIGNAL("activated()"),
+			self.show_about)
 
 	def set_defaults(self):
 		self.ui.resolution.setCurrentIndex(3) # '8'
@@ -126,7 +130,14 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		for x in range(self.ui.blocks.count()):
 			res += str(self.ui.blocks.item(x).text()) + ","
 		return res[:-1]
-
+	
+	def show_about(self):
+		w = QtGui.QDialog()
+		i = Ui_aboutDialog()
+		i.setupUi(w)
+		w.show()
+		w.activateWindow()
+		w.exec_()
 
 	def start_simulation(self):
 		o = OptionClass()
